# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.thumbnail_aspect_mode import ThumbnailAspectMode
import pprint
import six


class Bif(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 height=None,
                 width=None,
                 distance=None,
                 filename=None,
                 outputs=None,
                 aspect_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, float, string_types, list[EncodingOutput], ThumbnailAspectMode) -> None
        super(Bif, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._height = None
        self._width = None
        self._distance = None
        self._filename = None
        self._outputs = list()
        self._aspect_mode = None
        self.discriminator = None

        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if distance is not None:
            self.distance = distance
        if filename is not None:
            self.filename = filename
        if outputs is not None:
            self.outputs = outputs
        if aspect_mode is not None:
            self.aspect_mode = aspect_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Bif, self), 'openapi_types'):
            types = getattr(super(Bif, self), 'openapi_types')

        types.update({
            'height': 'int',
            'width': 'int',
            'distance': 'float',
            'filename': 'string_types',
            'outputs': 'list[EncodingOutput]',
            'aspect_mode': 'ThumbnailAspectMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Bif, self), 'attribute_map'):
            attributes = getattr(super(Bif, self), 'attribute_map')

        attributes.update({
            'height': 'height',
            'width': 'width',
            'distance': 'distance',
            'filename': 'filename',
            'outputs': 'outputs',
            'aspect_mode': 'aspectMode'
        })
        return attributes

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this Bif.

        Height of one thumbnail

        :return: The height of this Bif.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this Bif.

        Height of one thumbnail

        :param height: The height of this Bif.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this Bif.

        Width of one thumbnail. Roku recommends a width of 240 for SD and 320 for HD.

        :return: The width of this Bif.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this Bif.

        Width of one thumbnail. Roku recommends a width of 240 for SD and 320 for HD.

        :param width: The width of this Bif.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def distance(self):
        # type: () -> float
        """Gets the distance of this Bif.

        Distance in seconds between a screenshot (required)

        :return: The distance of this Bif.
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        # type: (float) -> None
        """Sets the distance of this Bif.

        Distance in seconds between a screenshot (required)

        :param distance: The distance of this Bif.
        :type: float
        """

        if distance is not None:
            if distance is not None and distance < 0:
                raise ValueError("Invalid value for `distance`, must be a value greater than or equal to `0`")
            if not isinstance(distance, (float, int)):
                raise TypeError("Invalid type for `distance`, type has to be `float`")

        self._distance = distance

    @property
    def filename(self):
        # type: () -> string_types
        """Gets the filename of this Bif.

        Filename of the Bif image. (required)

        :return: The filename of this Bif.
        :rtype: string_types
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        # type: (string_types) -> None
        """Sets the filename of this Bif.

        Filename of the Bif image. (required)

        :param filename: The filename of this Bif.
        :type: string_types
        """

        if filename is not None:
            if not isinstance(filename, string_types):
                raise TypeError("Invalid type for `filename`, type has to be `string_types`")

        self._filename = filename

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this Bif.


        :return: The outputs of this Bif.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this Bif.


        :param outputs: The outputs of this Bif.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def aspect_mode(self):
        # type: () -> ThumbnailAspectMode
        """Gets the aspect_mode of this Bif.

        Specifies the aspect mode that is used when both height and width are specified Only supported starting with encoder version `2.85.0`. 

        :return: The aspect_mode of this Bif.
        :rtype: ThumbnailAspectMode
        """
        return self._aspect_mode

    @aspect_mode.setter
    def aspect_mode(self, aspect_mode):
        # type: (ThumbnailAspectMode) -> None
        """Sets the aspect_mode of this Bif.

        Specifies the aspect mode that is used when both height and width are specified Only supported starting with encoder version `2.85.0`. 

        :param aspect_mode: The aspect_mode of this Bif.
        :type: ThumbnailAspectMode
        """

        if aspect_mode is not None:
            if not isinstance(aspect_mode, ThumbnailAspectMode):
                raise TypeError("Invalid type for `aspect_mode`, type has to be `ThumbnailAspectMode`")

        self._aspect_mode = aspect_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Bif, self), "to_dict"):
            result = super(Bif, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Bif):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class OttLoudnessMode(Enum):
    DTSX_OTT_LOUDNESS_DETECT = "DTSX_OTT_LOUDNESS_DETECT"
    DTSX_OTT_LOUDNESS_INPUT = "DTSX_OTT_LOUDNESS_INPUT"
    DTSX_OTT_LOUDNESS_TARGET = "DTSX_OTT_LOUDNESS_TARGET"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_muxing_representation import DashMuxingRepresentation
from bitmovin_api_sdk.models.dash_representation_type import DashRepresentationType
from bitmovin_api_sdk.models.dash_representation_type_mode import DashRepresentationTypeMode
import pprint
import six


class DashSegmentedRepresentation(DashMuxingRepresentation):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 encoding_id=None,
                 muxing_id=None,
                 dependency_id=None,
                 type_=None,
                 mode=None,
                 segment_path=None,
                 start_segment_number=None,
                 end_segment_number=None,
                 start_keyframe_id=None,
                 end_keyframe_id=None):
        # type: (string_types, string_types, string_types, string_types, DashRepresentationType, DashRepresentationTypeMode, string_types, int, int, string_types, string_types) -> None
        super(DashSegmentedRepresentation, self).__init__(id_=id_, encoding_id=encoding_id, muxing_id=muxing_id, dependency_id=dependency_id)

        self._type = None
        self._mode = None
        self._segment_path = None
        self._start_segment_number = None
        self._end_segment_number = None
        self._start_keyframe_id = None
        self._end_keyframe_id = None
        self.discriminator = None

        if type_ is not None:
            self.type = type_
        if mode is not None:
            self.mode = mode
        if segment_path is not None:
            self.segment_path = segment_path
        if start_segment_number is not None:
            self.start_segment_number = start_segment_number
        if end_segment_number is not None:
            self.end_segment_number = end_segment_number
        if start_keyframe_id is not None:
            self.start_keyframe_id = start_keyframe_id
        if end_keyframe_id is not None:
            self.end_keyframe_id = end_keyframe_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DashSegmentedRepresentation, self), 'openapi_types'):
            types = getattr(super(DashSegmentedRepresentation, self), 'openapi_types')

        types.update({
            'type': 'DashRepresentationType',
            'mode': 'DashRepresentationTypeMode',
            'segment_path': 'string_types',
            'start_segment_number': 'int',
            'end_segment_number': 'int',
            'start_keyframe_id': 'string_types',
            'end_keyframe_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DashSegmentedRepresentation, self), 'attribute_map'):
            attributes = getattr(super(DashSegmentedRepresentation, self), 'attribute_map')

        attributes.update({
            'type': 'type',
            'mode': 'mode',
            'segment_path': 'segmentPath',
            'start_segment_number': 'startSegmentNumber',
            'end_segment_number': 'endSegmentNumber',
            'start_keyframe_id': 'startKeyframeId',
            'end_keyframe_id': 'endKeyframeId'
        })
        return attributes

    @property
    def type(self):
        # type: () -> DashRepresentationType
        """Gets the type of this DashSegmentedRepresentation.


        :return: The type of this DashSegmentedRepresentation.
        :rtype: DashRepresentationType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (DashRepresentationType) -> None
        """Sets the type of this DashSegmentedRepresentation.


        :param type_: The type of this DashSegmentedRepresentation.
        :type: DashRepresentationType
        """

        if type_ is not None:
            if not isinstance(type_, DashRepresentationType):
                raise TypeError("Invalid type for `type`, type has to be `DashRepresentationType`")

        self._type = type_

    @property
    def mode(self):
        # type: () -> DashRepresentationTypeMode
        """Gets the mode of this DashSegmentedRepresentation.


        :return: The mode of this DashSegmentedRepresentation.
        :rtype: DashRepresentationTypeMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        # type: (DashRepresentationTypeMode) -> None
        """Sets the mode of this DashSegmentedRepresentation.


        :param mode: The mode of this DashSegmentedRepresentation.
        :type: DashRepresentationTypeMode
        """

        if mode is not None:
            if not isinstance(mode, DashRepresentationTypeMode):
                raise TypeError("Invalid type for `mode`, type has to be `DashRepresentationTypeMode`")

        self._mode = mode

    @property
    def segment_path(self):
        # type: () -> string_types
        """Gets the segment_path of this DashSegmentedRepresentation.

        Path to segments. Will be used as the representation id if the type is set to TEMPLATE_ADAPTATION_SET (required)

        :return: The segment_path of this DashSegmentedRepresentation.
        :rtype: string_types
        """
        return self._segment_path

    @segment_path.setter
    def segment_path(self, segment_path):
        # type: (string_types) -> None
        """Sets the segment_path of this DashSegmentedRepresentation.

        Path to segments. Will be used as the representation id if the type is set to TEMPLATE_ADAPTATION_SET (required)

        :param segment_path: The segment_path of this DashSegmentedRepresentation.
        :type: string_types
        """

        if segment_path is not None:
            if not isinstance(segment_path, string_types):
                raise TypeError("Invalid type for `segment_path`, type has to be `string_types`")

        self._segment_path = segment_path

    @property
    def start_segment_number(self):
        # type: () -> int
        """Gets the start_segment_number of this DashSegmentedRepresentation.

        Number of the first segment

        :return: The start_segment_number of this DashSegmentedRepresentation.
        :rtype: int
        """
        return self._start_segment_number

    @start_segment_number.setter
    def start_segment_number(self, start_segment_number):
        # type: (int) -> None
        """Sets the start_segment_number of this DashSegmentedRepresentation.

        Number of the first segment

        :param start_segment_number: The start_segment_number of this DashSegmentedRepresentation.
        :type: int
        """

        if start_segment_number is not None:
            if not isinstance(start_segment_number, int):
                raise TypeError("Invalid type for `start_segment_number`, type has to be `int`")

        self._start_segment_number = start_segment_number

    @property
    def end_segment_number(self):
        # type: () -> int
        """Gets the end_segment_number of this DashSegmentedRepresentation.

        Number of the last segment. Default is the last one that was encoded

        :return: The end_segment_number of this DashSegmentedRepresentation.
        :rtype: int
        """
        return self._end_segment_number

    @end_segment_number.setter
    def end_segment_number(self, end_segment_number):
        # type: (int) -> None
        """Sets the end_segment_number of this DashSegmentedRepresentation.

        Number of the last segment. Default is the last one that was encoded

        :param end_segment_number: The end_segment_number of this DashSegmentedRepresentation.
        :type: int
        """

        if end_segment_number is not None:
            if not isinstance(end_segment_number, int):
                raise TypeError("Invalid type for `end_segment_number`, type has to be `int`")

        self._end_segment_number = end_segment_number

    @property
    def start_keyframe_id(self):
        # type: () -> string_types
        """Gets the start_keyframe_id of this DashSegmentedRepresentation.

        Id of the keyframe to start with. It takes precedence over startSegmentNumber

        :return: The start_keyframe_id of this DashSegmentedRepresentation.
        :rtype: string_types
        """
        return self._start_keyframe_id

    @start_keyframe_id.setter
    def start_keyframe_id(self, start_keyframe_id):
        # type: (string_types) -> None
        """Sets the start_keyframe_id of this DashSegmentedRepresentation.

        Id of the keyframe to start with. It takes precedence over startSegmentNumber

        :param start_keyframe_id: The start_keyframe_id of this DashSegmentedRepresentation.
        :type: string_types
        """

        if start_keyframe_id is not None:
            if not isinstance(start_keyframe_id, string_types):
                raise TypeError("Invalid type for `start_keyframe_id`, type has to be `string_types`")

        self._start_keyframe_id = start_keyframe_id

    @property
    def end_keyframe_id(self):
        # type: () -> string_types
        """Gets the end_keyframe_id of this DashSegmentedRepresentation.

        Id of the keyframe to end with. It takes precedence over endSegmentNumber. The segment containing the end keyframe is not included in the representation.

        :return: The end_keyframe_id of this DashSegmentedRepresentation.
        :rtype: string_types
        """
        return self._end_keyframe_id

    @end_keyframe_id.setter
    def end_keyframe_id(self, end_keyframe_id):
        # type: (string_types) -> None
        """Sets the end_keyframe_id of this DashSegmentedRepresentation.

        Id of the keyframe to end with. It takes precedence over endSegmentNumber. The segment containing the end keyframe is not included in the representation.

        :param end_keyframe_id: The end_keyframe_id of this DashSegmentedRepresentation.
        :type: string_types
        """

        if end_keyframe_id is not None:
            if not isinstance(end_keyframe_id, string_types):
                raise TypeError("Invalid type for `end_keyframe_id`, type has to be `string_types`")

        self._end_keyframe_id = end_keyframe_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DashSegmentedRepresentation, self), "to_dict"):
            result = super(DashSegmentedRepresentation, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashSegmentedRepresentation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions import WebhookNotificationWithStreamConditions
from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions_request import WebhookNotificationWithStreamConditionsRequest


class EncodingStatusChangedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingStatusChangedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Add Encoding Changed Webhook Notification (All Encodings)

        :param webhook_notification_with_stream_conditions_request: The webhook notifications object. For conditions, following attributes are possible: &#39;type&#39;: &#39;Input file download&#39;, &#39;Input file analysis&#39;, &#39;Per-Title analysis&#39;, &#39;Encoding&#39;, &#39;Progressive Muxing&#39; &#39;progress&#39;: number in range of 0-100 &#39;status&#39;: &#39;RUNNING&#39;, &#39;FINISHED&#39;, &#39;ERROR&#39; Examples: To only get notified about the encoding process, create a Condition object and set attribute&#x3D;&#39;type&#39;, value&#x3D;&#39;Encoding&#39;, operator&#x3D;EQUAL To only get notified if a workflow step is finished, create a Condition object and set attribute&#x3D;&#39;status&#39;, value&#x3D;&#39;FINISHED&#39;, operator&#x3D;EQUAL To only get notified if a workflow step is over 50%,  create a Condition object and set attribute&#x3D;&#39;progress&#39;, value&#x3D;&#39;50&#39;, operator&#x3D;GREATER_THAN
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/encoding-status-changed',
            webhook_notification_with_stream_conditions_request,
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )

    def create_by_encoding_id(self, encoding_id, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (string_types, WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Add Encoding Changed Webhook Notification (Specific Encoding)

        :param encoding_id: Id of the encoding resource
        :type encoding_id: string_types, required
        :param webhook_notification_with_stream_conditions_request: The webhook notifications object. For conditions, following attributes are possible: &#39;type&#39;: &#39;Input file download&#39;, &#39;Input file analysis&#39;, &#39;Per-Title analysis&#39;, &#39;Encoding&#39;, &#39;Progressive Muxing&#39; &#39;progress&#39;: number in range of 0-100 &#39;status&#39;: &#39;RUNNING&#39;, &#39;FINISHED&#39;, &#39;ERROR&#39; Examples: To only get notified about the encoding process, create a Condition object and set attribute&#x3D;&#39;type&#39;, value&#x3D;&#39;Encoding&#39;, operator&#x3D;EQUAL To only get notified if a workflow step is finished, create a Condition object and set attribute&#x3D;&#39;status&#39;, value&#x3D;&#39;FINISHED&#39;, operator&#x3D;EQUAL To only get notified if a workflow step is over 50%,  create a Condition object and set attribute&#x3D;&#39;progress&#39;, value&#x3D;&#39;50&#39;, operator&#x3D;GREATER_THAN 
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/encoding-status-changed',
            webhook_notification_with_stream_conditions_request,
            path_params={'encoding_id': encoding_id},
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )

    def delete_by_webhook_id(self, notification_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Encoding Status Changed Webhook

        :param notification_id: Id of the webhook
        :type notification_id: string_types, required
        :return: Id of the webhook
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/webhooks/encoding/encodings/encoding-status-changed/{notification_id}',
            path_params={'notification_id': notification_id},
            type=BitmovinResponse,
            **kwargs
        )

    def update(self, notification_id, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (string_types, WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Replace Encoding Status Changed Webhook Notification

        :param notification_id: Id of the webhook notification
        :type notification_id: string_types, required
        :param webhook_notification_with_stream_conditions_request: The webhook notification with the updated values
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.put(
            '/notifications/webhooks/encoding/encodings/encoding-status-changed/{notification_id}',
            webhook_notification_with_stream_conditions_request,
            path_params={'notification_id': notification_id},
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EncryptionMode(Enum):
    CTR = "CTR"
    CBC = "CBC"
